#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.system_service import SystemService


class Analyze(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Analyze
                |
                | Represents the analysis object associated with a product.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analyze = com_object

    @property
    def mass(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Mass() As double (Read Only)
                |
                |     Returns the product mass value.
                |
                |     Example:
                |
                |           This example retrieves MassValue from
                |
                |          the Analyze object associated with myProduct:
                |
                |
                |          MassValue = myProduct.Analyze.Mass

        :return: float
        :rtype: float
        """

        return self.analyze.Mass

    @property
    def volume(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Volume() As double (Read Only)
                |
                |     Returns the product volume value.
                |
                |     Example:
                |
                |           This example retrieves VolumeValue from
                |
                |          the Analyze object associated with myProduct:
                |
                |
                |          VolumeValue = myProduct.Analyze.Volume

        :return: float
        :rtype: float
        """

        return self.analyze.Volume

    @property
    def wet_area(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property WetArea() As double (Read Only)
                |
                |     Returns the product wet area (outer volume).
                |
                |
                |     Note:
                |     This method uses mm2 instead of default Catia V5 unit.
                |
                |     Example:
                |
                |           This example retrieves WetAreaValue from
                |
                |          the Analyze object associated with myProduct:
                |
                |
                |          WetAreaValue = myProduct.Analyze.WetArea

        :return: float
        :rtype: float
        """

        return self.analyze.WetArea

    def get_gravity_center(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetGravityCenter(CATSafeArrayVariant
                | oGravityCenterCoordinatesArray)
                |
                |     Returns the gravity center coordinates of product.
                |
                |     Parameters:
                |
                |         Coordinates
                |             The array storing the three gravity center coordinates. This array
                |             must be previously initialized.
                |
                |     Example:
                |
                |           This example retrieves the gravity center coordinates
                |           in
                |          oGravityCenterCoordinatesArray from
                |          the Analyze object associated with myProduct:
                |
                |          ' Coordinates array initialization
                |          Dim oGravityCenterCoordinatesArray ( 2 )
                |          ' Get value in array
                |          Myproduct.Analyze.GetGravityCenter
                |          oGravityCenterCoordinatesArray

        :return: None
        """
        # return self.analyze.GetGravityCenter(o_gravity_center_coordinates_array)
        # # # # Autogenerated comment:
        # some methods require a system service call as the methods expects a vb array object
        # passed to it and there is no way to do this directly with python. In those cases the following code
        # should be uncommented and edited accordingly. Otherwise completely remove all this.
        vba_function_name = 'get_gravity_center'
        vba_code = """
        Public Function get_gravity_center(analyze)
            Dim oGravityCenterCoordinatesArray (2)
            analyze.GetGravityCenter oGravityCenterCoordinatesArray
            get_gravity_center = oGravityCenterCoordinatesArray
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_inertia(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetInertia(CATSafeArrayVariant oInertiaMatrixArray)
                |
                |     Returns the inertia matrix array of product.
                |
                |     Parameters:
                |
                |         oInertiaMatrixArray
                |             The array storing successively the three columns of inertia matrix.
                |             This array must be previously initialized.
                |
                |     Example:
                |
                |           This example retrieves the inertia matrix components
                |           in
                |          oInertiaMatrixArray from
                |          the Analyze object associated with myProduct:
                |
                |
                |          ' Components array initialization
                |          Dim oInertiaMatrixArray ( 8 )
                |          ' Get value in array
                |          Myproduct.Analyze.GetInertia oInertiaMatrixArray
                |          ' oInertiaMatrixArray ( 0 ) is the Ixx component
                |          ' oInertiaMatrixArray ( 1 ) is the Ixy component
                |          ' oInertiaMatrixArray ( 2 ) is the Ixz component
                |          ' oInertiaMatrixArray ( 3 ) is the Iyx component
                |          ' oInertiaMatrixArray ( 4 ) is the Iyy component
                |          ' oInertiaMatrixArray ( 5 ) is the Iyz component
                |          ' oInertiaMatrixArray ( 6 ) is the Izx component
                |          ' oInertiaMatrixArray ( 7 ) is the Izy component
                |          ' oInertiaMatrixArray ( 8 ) is the Izz component

        :return: tuple
        """
        # return self.analyze.GetInertia(o_inertia_matrix_array)
        # # # Autogenerated comment:
        # some methods require a system service call as the methods expects a vb array object
        # passed to it and there is no way to do this directly with python. In those cases the following code
        # should be uncommented and edited accordingly. Otherwise completely remove all this.
        vba_function_name = 'get_inertia'
        vba_code = """
        Public Function get_inertia(analyze)
            Dim oInertiaMatrixArray (8)
            analyze.GetInertia oInertiaMatrixArray
            get_inertia = oInertiaMatrixArray
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Analyze(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SettingController(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SettingController
                | 
                | Represents the base object for setting controllers.
                | Role: A setting controller manages all or only a part of the parameters
                | available in a property page of the dialog displayed using the Options command
                | of the Tools menu. Each setting parameter may be represented by one or several
                | setting attribute in the underlying setting repository.
                | 
                | All setting controllers share the five methods of the SettingController object
                | to deal with the whole set, or a subset of the setting
                | attributes:
                | 
                |     Commit to make a memory copy of the setting attribute
                |     values
                |     Rollback to restore the last memory copy of the setting attribute
                |     values
                |     ResetToAdminValues to restore the administered values of all the
                |     attributes
                |     ResetToAdminValuesByName to restore the administered values of a subset of
                |     the attributes
                |     SaveRepository to make a persistent copy of the setting attribute values on
                |     file.
                | 
                | In addition, each setting controller exposes four methods per setting
                | parameter: two methods to access the setting attribute values, that usually
                | make up a read/write property if the setting parameter is represented by a
                | single setting attribute, a method to manage the setting parameter lock, and a
                | method to retrieve the state of the setting parameter. The first two methods
                | are parameter-specific and are fully described in the setting controller object
                | that managing the setting parameter. The last two methods have always the same
                | signature and the same behavior whatever the setting parameter. They are
                | described below. PARAMETER is used in place of the actual setting parameter
                | name.
                | 
                |     Managing the Setting Parameter Lock
                | 
                |     HRESULT SetPARAMETERLock(in  boolean iLocked);
                | 
                |     Locks or unlocks the PARAMETER setting parameter.
                |     Role: Locking a setting parameter prevents the end user, or the
                |     administrators below the current one, from changing the setting parameter
                |     value. Locking or unlocking the PARAMETER setting parameter is an administrator
                |     task and is possible when running a session in the administration mode
                |     only.
                | 
                |     Parameters
                | 
                |         iLocked
                |             [in] A flag to indicate whether the PARAMETER setting parameter
                |             should be locked.
                |             Legal values: True to lock, and False to unlock.
                | 
                | 
                |     Retrieving the Setting Parameter State
                | 
                |     HRESULT GetPARAMETERInfo (inout CATBSTR ioAdminLevel,
                |                                     inout CATBSTR ioLocked,
                |                                     out  /*IDLRETVAL*/ boolean
                |                                     oModified);
                | 
                |     Retrieves information about the PARAMETER setting
                |     parameter.
                |     Role: This information defines the state of the setting parameter and is
                |     made up of:
                |         The administration level that sets the current value or the value used
                |         to reset it
                |         The administration level that has locked the setting
                |         parameter.
                |         A flag to indicate whether the setting parameter was
                |         modified.
                | 
                |     Parameters
                | 
                |         ioAdminLevel
                |             [inout] The administration leve that defines the value used when
                |             resetting the setting parameter.
                | 
                |             Legal values:
                |                 Default value if the setting parameter has never been
                |                 explicitly set in the administration
                |                 concatenation.
                |                 Set at Admin Level n if the setting parameter has been
                |                 administered,
                |                 where n is an integer starting from 0 representing the rank of
                |                 the administration level.
                |         ioLocked
                |             [inout] A character string to indicate whether the parameter is
                |             locked and the level of administration where the locking has been
                |             proceeded.
                |             Legal values:
                |                 Locked at Admin Level n if the setting parameter is locked by
                |                 then administration level n,
                |                 where n is an integer starting from 0. The setting parameter
                |                 can not be modified at the current level.
                |                 Locked if the setting parameter is locked by the current
                |                 administration level. Only an admistrator can get this
                |                 value.
                |                 Unlocked if the setting parameter is not
                |                 locked
                | 
                |     Returns
                |         True to indicate that the setting parameter value has been explicitely
                |         modified at the current administrator or user level. This is only possible with
                |         unlocked parameters. False means that it inherits the administered
                |         value.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.setting_controller = com_object

    def commit(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub Commit()
                | 
                |     Makes a memory copy of the setting attribute values.
                |     Role: Commit saves the current values of the setting attributes managed by
                |     the setting controller in a specific memory area. Successive calls to Commit
                |     overwrite the memory area. The values saved by the last call to Commit can be
                |     restored from that memory area using the Rollback method.

        :return: None
        """
        return self.setting_controller.Commit()

    def reset_to_admin_values(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub ResetToAdminValues()
                | 
                |     Restores the administrated values of the all attributes.
                |     Role: ResetToAdminValues restores all the values of the setting attributes
                |     managed by the setting controller to either the values set by the setting
                |     administrator, or to their default values if the setting administrator did not
                |     change them.

        :return: None
        """
        return self.setting_controller.ResetToAdminValues()

    def reset_to_admin_values_by_name(self, i_att_list):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub ResetToAdminValuesByName(CATSafeArrayVariant iAttList)
                | 
                |     Restores the administrated values of a subset of the
                |     attributes.
                |     Role: ResetToAdminValuesByName restores the values of a subset of the
                |     setting attributes managed by the setting controller to either the values set
                |     by the setting administrator, or to their default values if the setting
                |     administrator did not change them.
                | 
                |     Parameters:
                | 
                |         iAttList
                |             The attribute subset to which the administrated values are to be
                |             restored

        :param tuple i_att_list:
        :return: None
        """
        return self.setting_controller.ResetToAdminValuesByName(i_att_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'reset_to_admin_values_by_name'
        # # vba_code = """
        # # Public Function reset_to_admin_values_by_name(setting_controller)
        # #     Dim iAttList (2)
        # #     setting_controller.ResetToAdminValuesByName iAttList
        # #     reset_to_admin_values_by_name = iAttList
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def rollback(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub Rollback()
                | 
                |     Restores the last memory copy of the setting attribute
                |     values.
                |     Role: Rollback restores the values of the setting attributes managed by the
                |     setting controller from the memory area. All values of the setting attributes
                |     managed by the setting controller modified since the last call to Commit are
                |     restored to the values they had when this last Commit was called.

        :return: None
        """
        return self.setting_controller.Rollback()

    def save_repository(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SaveRepository()
                | 
                |     Makes a persistent copy of the setting attribute values on
                |     file.
                |     Role: SaveRepository saves the current values of the setting attributes
                |     managed by the setting controller in a setting repository file. To avoid
                |     inconsistencies, SaveRepository first saves the values in the memory area used
                |     by the Commit method by calling Commit before writing the values in the setting
                |     repository file.

        :return: None
        """
        return self.setting_controller.SaveRepository()

    def __repr__(self):
        return f'SettingController(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeThickness(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeThickness
                | 
                | Represents the hybrid shape Thickness feature object.
                | Role: To access the data of the thickness on an hybrid shape feature object.
                | This data includes:
                | 
                |     The thickness orientation
                |     The thickness1 value
                |     The thickness2 value
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_thickness = com_object

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation() As long
                | 
                |     Returns or sets the orientation.
                |     Role:
                |     Orientation
                |     1 means that the first thickness is measured with the normal of the support Orientation
                |     -1 means that the first thickness is measured with the inverted normal of the support
                | 
                |     Example:
                |         This example retrieves in Orient the orientation for the Thickness1
                |         hybrid shape feature.
                | 
                |          Dim Orient As long
                |          Set Orient = Thickness1.Orientation

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_thickness.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_thickness.Orientation = value

    @property
    def thickness1(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Thickness1() As double
                | 
                |     Returns or sets the first thickness value in mm.
                | 
                |     Example: This example retrieves in ThickVal1 the first thickness value for
                |     the Thick hybrid shape feature.
                | 
                |      Dim ThickVal1 As double
                |      Set ThickVal1 = Thick.Thickness1

        :return: float
        :rtype: float
        """

        return self.hybrid_shape_thickness.Thickness1

    @thickness1.setter
    def thickness1(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_thickness.Thickness1 = value

    @property
    def thickness1_value(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Thickness1Value() As Length (Read Only)
                | 
                |     Returns the first thickness value.
                | 
                |     Example:
                |         This example retrieves in ThickVal1 the first thickness value for the
                |         Thick hybrid shape feature.
                | 
                |          Dim ThickVal1 As Length
                |          Set ThickVal1 = Thick.Thickness1Value

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_thickness.Thickness1Value)

    @property
    def thickness2(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Thickness2() As double
                | 
                |     Returns or sets the second thickness value in mm.
                | 
                |     Example: This example retrieves in ThickVal2 the second thickness value for
                |     the Thick hybrid shape feature.
                | 
                |      Dim ThickVal2 As double
                |      Set ThickVal2 = Thick.Thickness2

        :return: float
        :rtype: float
        """

        return self.hybrid_shape_thickness.Thickness2

    @thickness2.setter
    def thickness2(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_thickness.Thickness2 = value

    @property
    def thickness2_value(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Thickness2Value() As Length (Read Only)
                | 
                |     Returns the second thickness value.
                | 
                |     Example:
                |         This example retrieves in ThickVal2 the second thickness value for the
                |         Thick hybrid shape feature.
                | 
                |          Dim ThickVal2 As Length
                |          Set ThickVal2 = Thick.Thickness2Value

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_thickness.Thickness2Value)

    def __repr__(self):
        return f'HybridShapeThickness(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.sketcher_interfaces.geometry_2D import Geometry2D
from pycatia.sketcher_interfaces.point_2D import Point2D
from pycatia.system_interfaces.system_service import SystemService


class Curve2D(Geometry2D):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SketcherInterfaces.GeometricElement
                |                         SketcherInterfaces.Geometry2D
                |                             Curve2D
                | 
                | Class defining a curve in 2D Space.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.curve_2d = com_object

    @property
    def continuity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Continuity() As short (Read Only)
                | 
                |     Returns the highest level of geometric continuity the curve
                |     possesses.
                | 
                |     Parameters:
                | 
                |         oLevel
                |             The maximum geometric continuity level

        :return: int
        :rtype: int
        """

        return self.curve_2d.Continuity

    @property
    def end_point(self) -> Point2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EndPoint() As Point2D
                | 
                |     Returns the end point of the curve. The end point is decided with respect
                |     to the logical flow imposed on the curve by the object.
                | 
                |     Parameters:
                | 
                |         oEndPoint
                |             The end point of the curve

        :return: Point2D
        :rtype: Point2D
        """

        return Point2D(self.curve_2d.EndPoint)

    @end_point.setter
    def end_point(self, end_point: Point2D):
        """
        :param Point2D end_point:
        """

        self.curve_2d.EndPoint = end_point.com_object

    @property
    def period(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Period() As double (Read Only)
                | 
                |     Returns the period of a periodic curve.
                | 
                |     Parameters:
                | 
                |         oPeriod
                |             The period of the curve.

        :return: float
        :rtype: float
        """

        return self.curve_2d.Period

    @property
    def start_point(self) -> Point2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property StartPoint() As Point2D
                | 
                |     Returns the start point of the curve. The start point is decided with
                |     respect to the logical flow imposed on the curve by the
                |     object.
                | 
                |     Parameters:
                | 
                |         oStartPoint
                |             The start point of the curve

        :return: Point2D
        :rtype: Point2D
        """

        return Point2D(self.curve_2d.StartPoint)

    @start_point.setter
    def start_point(self, start_point: Point2D):
        """
        :param Point2D start_point:
        """

        self.curve_2d.StartPoint = start_point.com_object

    def get_curvature(self, i_param: float) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetCurvature(double iParam,
                | CATSafeArrayVariant oCurvature)
                | 
                |     Returns the curvature and curvature direction at the parameter
                |     specified.
                | 
                |     Parameters:
                | 
                |         iParam
                |             The parameter of the chosen point on the curve. 
                |         oCurvature[0]
                |             The curvature at the specified parameter. 
                |         oCurvature[1;2]
                |             The unit-vector of curvature direction at the specified
                |             parameter.

        :param float i_param:
        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_curvature'
        vba_code = """
        Public Function get_curvature(curve2_d, i_param)
            Dim oCurvature (2)
            curve2_d.GetCurvature i_param, oCurvature
            get_curvature = oCurvature
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object, i_param])

    def get_derivatives(self, i_param: float) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetDerivatives(double iParam,
                | CATSafeArrayVariant oDerivative)
                | 
                |     Returns the first, second and third derivatives at the parameter
                |     specified.
                | 
                |     Parameters:
                | 
                |         iParam
                |             The parameter of the chosen point on the curve. 
                |         oDerivative[0]
                |             First degree derivative. 
                |         oDerivative[1]
                |             Second degree derivative. 
                |         oDerivative[2]
                |             Third degree derivative.

        :param float i_param:
        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_derivatives'
        vba_code = """
        Public Function get_derivatives(curve2_d, i_param)
            Dim oDerivative(2)
            curve2_d.GetDerivatives iParam, oDerivative
            get_derivatives = oDerivative
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object, i_param])

    def get_end_points(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetEndPoints(CATSafeArrayVariant oEndPoints)
                | 
                |     Returns the end-points of the curve. The start point and the end point are
                |     decided with respect to the logical flow imposed on the curve by the
                |     object.
                | 
                |     Parameters:
                | 
                |         oEndPoints[0]
                |             The x coordinate of the start point 
                |         oEndPoints[1]
                |             The y coordinate of the start point 
                |         oEndPoints[2]
                |             The x coordinate of the end point 
                |         oEndPoints[3]
                |             The y coordinate of the end point

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_end_points'
        vba_code = """
        Public Function get_end_points(curve2_d)
            Dim oEndPoints (3)
            curve2_d.GetEndPoints oEndPoints
            get_end_points = oEndPoints
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_length_at_param(self, i_from_param: float, i_to_param: float) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLengthAtParam(double iFromParam,
                | double iToParam) As double
                | 
                |     Returns the length, measured along the curve, from a given parameter to a
                |     given parameter.
                | 
                |     Parameters:
                | 
                |         iFromParam
                |             The parameter from which the length is to be measured.
                |             
                |         iToParam
                |             The parameter to which the length is to be measured.
                |             
                |         oLength
                |             The length between the parameters

        :param float i_from_param:
        :param float i_to_param:
        :return: float
        :rtype: float
        """
        return self.curve_2d.GetLengthAtParam(i_from_param, i_to_param)

    def get_param_at_length(self, i_from_param: float, i_length: float) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetParamAtLength(double iFromParam,
                | double iLength) As double
                | 
                |     Returns the parameter at a given length, measured along the curve, starting
                |     from a given parameter. The direction of measurement is always in the direction
                |     of the logical flow of the curve. If no inherent logical flow can be assigned
                |     the direction is the direction of increasing
                |     parameterization.
                | 
                |     Parameters:
                | 
                |         iFromParam
                |             The parameter from which the length needs to be measured.
                |             
                |         iLength
                |             The length of the curve to be measured from iFromParam in the
                |             logical flow direction of the curve. 
                |         oParam
                |             The computed parameter.

        :param float i_from_param:
        :param float i_length:
        :return: float
        :rtype: float
        """
        return self.curve_2d.GetParamAtLength(i_from_param, i_length)

    def get_param_extents(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetParamExtents(CATSafeArrayVariant oParams)
                | 
                |     Returns the parametric extents of the curve. This is the parametric
                |     equivalent of the end-points.
                | 
                |     Parameters:
                | 
                |         oParams[0]
                |             The parameter associated with the start point of the curve
                |             
                |         oParams[1]
                |             The parameter associated with the end point of the
                |             curve

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_param_extents'
        vba_code = """
        Public Function get_param_extents(curve2_d)
            Dim oParams(1)
            curve2_d.GetParamExtents oParams
            get_param_extents = oParams
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_point_at_param(self, i_param: float) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPointAtParam(double iParam,
                | CATSafeArrayVariant oPoint)
                | 
                |     Returns a point on the curve computed from an input
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iParam
                |             The parameter 
                |         oPoint
                |             The X and Y coordinates of the computed 2D space
                |             point.

        :param float i_param:
        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_point_at_param'
        vba_code = """
        Public Function get_point_at_param(curve2_d, i_param)
            Dim oPoint (1)
            curve2_d.GetPointAtParam i_param, oPoint
            get_point_at_param = oPoint
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object, i_param])

    def get_range_box(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetRangeBox(CATSafeArrayVariant oBoundPoint)
                | 
                |     Returns the range box (or bounding box) of the object
                |     The box is axially aligned within the local coordinate system of the
                |     server.
                | 
                |     Parameters:
                | 
                |         oBoundPoint[0]
                |             The minimum x point of the box 
                |         oBoundPoint[1]
                |             The minimum y point of the box 
                |         oBoundPoint[2]
                |             The maximum x point of the box 
                |         oBoundPoint[3]
                |             The maximum y point of the box

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_range_box'
        vba_code = """
        Public Function get_range_box(curve2_d)
            Dim oBoundPoint(3)
            curve2_d.GetRangeBox oBoundPoint
            get_range_box = oBoundPoint
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_tangent(self, i_param: float) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetTangent(double iParam,
                | CATSafeArrayVariant oTangency)
                | 
                |     Returns the unit-vector tangent at the parameter
                |     specified.
                | 
                |     Parameters:
                | 
                |         iParam
                |             The parameter of the chosen point on the curve. 
                |         oTangency
                |             The X and Y coordinates of the unit-vector tangent at the specified
                |             parameter.

        :i_param: float
        :return: None
        :rtype: None
        """

        vba_function_name = 'get_tangent'
        vba_code = """
        Public Function get_tangent(curve2_d, i_param)
            Dim oTangency(1)
            curve2_d.GetTangent i_param, oTangency
            get_tangent = oTangency
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object, i_param])

    def is_periodic(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func IsPeriodic() As boolean
                | 
                |     Specifies whether a curve is periodic or not.
                | 
                |     Parameters:
                | 
                |         oPeriodic
                |             Returns true if the curve is periodic.

        :return: bool
        :rtype: bool
        """
        return self.curve_2d.IsPeriodic()

    def __repr__(self):
        return f'Curve2D(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.drafting_interfaces.drawing_dimension import DrawingDimension
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class DrawingDimensions(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DrawingDimensions
                | 
                | A collection of all the drawing dimensions currently managed by a drawing view
                | of drawing sheet in a drawing document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=DrawingDimension)
        self.drawing_dimensions = com_object

    def add(self, i_type_dim: int, i_geom_elem: tuple, i_pt_coord_elem: tuple, i_line_rep: int) -> DrawingDimension:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add(CatDimType iTypeDim,
                | CATSafeArrayVariant iGeomElem,
                | CATSafeArrayVariant iPtCoordElem,
                | CatDimLineRep iLineRep) As DrawingDimension
                | 
                |     Creates a drawing dimension and adds it to the DrawingDimensions
                |     collection.
                | 
                |     Parameters:
                | 
                |         iTypeDim
                |             Dimension type 
                |         iGeomElem
                |             Parent geometrical element(s) of dimension 
                |         iPtCoordElem
                |             Array of pointers on the selection points of each element of
                |             iGeomElem 
                |         iLineRep
                |             Basic representation mode 
                | 
                |     Returns:
                |         The created drawing dimension 
                | 
                | Example:
                |     The following example creates a drawing angle dimension between two lines
                |     and a partial curvilinear length dimension on an ellipse and retrieved in
                |     MyDimension1 and MyDimension2 in the drawing view collection of the MyView
                |     drawing view. This view belongs to the drawing view collection of the drawing
                |     sheet
                | 
                |      Dim MyView As DrawingView
                |      Set MyView = MySheet.Views.ActiveView
                |      Dim Fact2D  As Factory2D
                |      Set Fact2D = MyView.Factory2D
                |      Dim Line1 As Line2D
                |      Dim Line2 As Line2D
                |      Set Line1 = Fact2D.CreateLine(50, 10, 150, 10)
                |      Set Line2 = Fact2D.CreateLine(50, 10, 120, 100)
                |      Dim Ellipse1 As Ellipse2D
                |      Set Ellipse1 = Fact2D.CreateEllipse(-40, 100, 120, 180,120,90,0, 3)
                |      Dim Point1 As Point2D
                |      Dim Point2 As Point2D
                |      Set Point1 = Fact2D.CreatePoint(-10,190)
                |      Set Point2 = Fact2D.CreatePoint(-120,90)
                |      Dim iType As catDimType
                |      iType = catDimAngle
                |      Dim myElements1(1)
                |      myElements1(1) = Array(Line1,Line2)
                |      Dim selpoints(3)
                |      selpoints(3) = Array(150, 10, 120, 100)
                |      Dim MyDimension1 As DrawingDimension
                |      Set MyDimension1 = MyView.Dimensions.Add(iType, myElements1(1), selpoints(3),catDimAuto)
                |      iType = catDimLengthCurvilinear
                |      Dim myElements2(2)
                |      myElements2(2) = Array(Point1,Point2,Ellipse1)
                |      selpoints(3) = Array(0, 0, 0, 0)
                |      Dim MyDimension2 As DrawingDimension
                |      Set MyDimension2 = MyView.Dimensions.Add(iType, myElements2(1), selpoints(3),catDimOffset)

        :param int i_type_dim:
        :param tuple i_geom_elem:
        :param tuple i_pt_coord_elem:
        :param int i_line_rep:
        :return: DrawingDimension
        :rtype: DrawingDimension
        """
        return DrawingDimension(
            self.drawing_dimensions.Add(
                i_type_dim,
                i_geom_elem,
                i_pt_coord_elem,
                i_line_rep)
        )

    def add2(self,
             i_type_dim: int,
             i_geom_elem: tuple,
             i_pt_coord_elem: tuple,
             i_ldc_ref_elem: cat_variant,
             i_ldc_ref_angle: int) -> DrawingDimension:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add2(CatDimType iTypeDim,
                | CATSafeArrayVariant iGeomElem,
                | CATSafeArrayVariant iPtCoordElem,
                | CATVariant iLDCRefElem,
                | long iLDCRefAngle) As DrawingDimension
                | 
                |     Creates a drawing dimension along a direction and adds it to the
                |     DrawingDimensions collection.
                | 
                |     Parameters:
                | 
                |         iTypeDim
                |             Dimension type (available types : catDimDistance, catDimLength, catDimRadiusTangent and
                |             catDimDiameterTangent)
                |         iGeomElem
                |             Parent geometrical element(s) of dimension
                |         iPtCoordElem
                |             Array of pointers on the selection points of each element of
                |             iGeomElem 
                |         iLDCRefElem
                |             Reference geometrical element for the direction of the dimension
                |             line .iLDCRefElem can be null: in this case, the view is the reference element
                |             
                |         iLDCRefAngle
                |             Angle between the reference element and the direction of the
                |             dimension line 
                | 
                |     Returns:
                |         The created drawing dimension (The property CATDimLineRep of the
                |         dimension line of the created dimension is set to catDimUserDefined)
                |         
                | 
                | Example:
                |     The following example creates a drawing distance dimension between two
                |     points along the direction of a line and retrieved in MyDimension in the
                |     drawing view collection of the MyView drawing view. This view belongs to the
                |     drawing view collection of the drawing sheet
                | 
                |      Dim MyView As DrawingView
                |      Set MyView = MySheet.Views.ActiveView
                |      Dim Fact2D  As Factory2D
                |      Set Fact2D = MyView.Factory2D
                |      Dim Point1 As Point2D
                |      Dim Point2 As Point2D
                |      Set Point1 = Fact2D.CreatePoint(40, 230)
                |      Set Point2 = Fact2D.CreatePoint(80, 210)
                |      Dim Line1 As Line2D
                |      Set Line1 = Fact2D.CreateLine(50, 10, 150, 10)
                |      Dim iType As catDimType
                |      iType = catDimDistance
                |      Dim myElements(1)
                |      myElements(1) = Array(Point1,Point2)
                |      Dim selpoints(3)
                |      selpoints(3) = Array(0, 0, 0, 0)
                |      Dim MyDimension As DrawingDimension
                |      Set MyDimension = MyView.Dimensions.Add2(iType, myElements(1), selpoints(3), Line1, 0)

        :param int i_type_dim:
        :param tuple i_geom_elem:
        :param tuple i_pt_coord_elem:
        :param CATVariant i_ldc_ref_elem:
        :param int i_ldc_ref_angle:
        :return: DrawingDimension
        :rtype: DrawingDimension
        """
        return DrawingDimension(
            self.drawing_dimensions.Add2(
                i_type_dim,
                i_geom_elem,
                i_pt_coord_elem,
                i_ldc_ref_elem,
                i_ldc_ref_angle)
        )

    def item(self, i_index: cat_variant) -> DrawingDimension:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As DrawingDimension
                | 
                |     Returns a drawing dimension using its index or its name from the
                |     DrawingDimensions collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the drawing dimension to retrieve from the
                |             collection of drawing dimensions. As a numerics, this index is the rank of the
                |             drawing dimension in the collection. The index of the first drawing dimension
                |             in the collection is 1, and the index of the last drawing dimension is Count.
                |             As a string, it is the name you assigned to the drawing dimension using the
                |             
                | 
                |         AnyObject.Name property or when creating it using the Add method.
                |         
                |     Returns:
                |         The retrieved drawing dimension 
                |     Example:
                | 
                |           This example retrieves in ThisDrawingDimension the second drawing
                |           dimension,
                |          and in ThatDrawingDimension the drawing dimension
                |          named
                |          MyDimension in the drawing dimension collection of the active
                |          view.
                |          
                | 
                |          Dim MyView As DrawingView
                |          Set MyView  = MySheet.Views.ActiveView
                |          Dim ThisDrawingDimension As DrawingDimension
                |          Set ThisDrawingDimension = MyView.Dimensions.Item(2)
                |          Dim ThatDrawingDimension As DrawingDimension
                |          Set ThatDrawingDimension = MyView.Dimensions.Item("MyDimension")

        :param cat_variant i_index:
        :return: DrawingDimension
        :rtype: DrawingDimension
        """
        return DrawingDimension(self.drawing_dimensions.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a drawing dimension from the DrawingDimensions
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the drawing dimension to remove from the collection of
                |             drawing dimensions. As a numerics, this index is the rank of the drawing
                |             dimension in the collection. The index of the first drawing dimension in the
                |             collection is 1, and the index of the last drawing dimension is Count.
                |             
                | 
                |     Example:
                |         The following example removes the third drawing dimension in the
                |         drawing dimension collection of the active view of the active document,
                |         supposed to be a drawing document.
                | 
                |          Dim MyView As DrawingView
                |          Set MyView  = MySheet.Views.ActiveView
                |          MyView.Dimensions.Remove(3)

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.drawing_dimensions.Remove(i_index)

    def __getitem__(self, n: int) -> DrawingDimension:
        if (n + 1) > self.count:
            raise StopIteration

        return DrawingDimension(self.drawing_dimensions.item(n + 1))

    def __iter__(self) -> Iterator[DrawingDimension]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'DrawingDimensions(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class GeneralStatisticsSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         GeneralStatisticsSettingAtt
                | 
                | Interface for General statistic Controller.
                | 
                | Role: the General statistics controller is a generic interface for all the
                | thematics. One should never use it as a statistics thematic.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.general_statistics_setting_att = com_object

    @property
    def activation(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property Activation() As boolean
                | 
                |     Returns or sets the activation state of the statistics
                |     thematic.
                |     Role: Returns or sets the value of statistics thematic activation.

        :return: bool
        """

        return self.general_statistics_setting_att.Activation

    @activation.setter
    def activation(self, value):
        """
        :param bool value:
        """

        self.general_statistics_setting_att.Activation = value

    @property
    def cpus(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property CPUS() As boolean
                | 
                |     Returns or sets the state ot the cpu time field.
                |     Role: Returns or sets the state ot the cpu time field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.general_statistics_setting_att.CPUS

    @cpus.setter
    def cpus(self, value):
        """
        :param bool value:
        """

        self.general_statistics_setting_att.CPUS = value

    @property
    def cumulation_mode(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property CumulationMode() As boolean
                | 
                |     Returns or sets the cumulation state of the statistics
                |     thematic.
                |     Role: Returns or sets the value of statistics thematic cumulation.

        :return: bool
        """

        return self.general_statistics_setting_att.CumulationMode

    @cumulation_mode.setter
    def cumulation_mode(self, value):
        """
        :param bool value:
        """

        self.general_statistics_setting_att.CumulationMode = value

    @property
    def date_format(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property DateFormat() As CATBSTR
                | 
                |     Returns or sets the state ot the date format field.
                |     Role: Returns or sets the state ot the date format field.
                | 
                |     Parameters:
                | 
                |         iDateFormat
                |             Legal values:
                |             StandardDate : default date format (Mon Jan 1 08:00.00 2000)
                |             NumericalDate: numerical date
                |             format(2000.001.08.00.00)
                |             NumericalDateMilliecond: numerical date
                |             format(2000.001.08.00.00.000)

        :return: str
        """

        return self.general_statistics_setting_att.DateFormat

    @date_format.setter
    def date_format(self, value):
        """
        :param str value:
        """

        self.general_statistics_setting_att.DateFormat = value

    @property
    def elps(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property ELPS() As boolean
                | 
                |     Returns or sets the state ot the elapsed time field.
                |     Role: Returns or sets the state ot the elapsed time field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.general_statistics_setting_att.ELPS

    @elps.setter
    def elps(self, value):
        """
        :param bool value:
        """

        self.general_statistics_setting_att.ELPS = value

    @property
    def host(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property HOST() As boolean
                | 
                |     Returns or sets the state ot the host name field.
                |     Role: Returns or sets the state ot the host name field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.general_statistics_setting_att.HOST

    @host.setter
    def host(self, value):
        """
        :param bool value:
        """

        self.general_statistics_setting_att.HOST = value

    @property
    def output(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property Output() As CATBSTR
                | 
                |     Returns or sets the output format of the statistics
                |     thematic.
                |     Role: Returns or sets the output format of the statistics
                |     thematic.
                | 
                |     Parameters:
                | 
                |         oOutputType
                |             Legal values:
                |             File :statistics are outputed in a file
                |             Console: statistics are outputed on the console (if
                |             available)

        :return: str
        """

        return self.general_statistics_setting_att.Output

    @output.setter
    def output(self, value):
        """
        :param str value:
        """

        self.general_statistics_setting_att.Output = value

    @property
    def output_file(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property OutputFile() As CATBSTR
                | 
                |     Returns or sets the path of the statistics thematic file.
                |     Role: Returns or sets the path of the statistics thematic file.

        :return: str
        """

        return self.general_statistics_setting_att.OutputFile

    @output_file.setter
    def output_file(self, value):
        """
        :param str value:
        """

        self.general_statistics_setting_att.OutputFile = value

    @property
    def output_format(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property OutputFormat() As CATBSTR
                | 
                |     Returns or sets the state ot the output format field.
                |     Role: Returns or sets the state ot the output format
                |     field.
                | 
                |     Parameters:
                | 
                |         iOutputFormat
                |             Legal values:
                |             StandardOutput: default format
                |             NoThematics : the thematic name is not repeated on each line

        :return: str
        """

        return self.general_statistics_setting_att.OutputFormat

    @output_format.setter
    def output_format(self, value):
        """
        :param str value:
        """

        self.general_statistics_setting_att.OutputFormat = value

    @property
    def rtim(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property RTIM() As boolean
                | 
                |     Returns or sets the state ot the response time field.
                |     Role: Returns or sets the state ot the response time
                |     field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.general_statistics_setting_att.RTIM

    @rtim.setter
    def rtim(self, value):
        """
        :param bool value:
        """

        self.general_statistics_setting_att.RTIM = value

    @property
    def them(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property THEM() As boolean
                | 
                |     Returns or sets the state ot the thematic field.
                |     Role: Returns or sets the state ot the thematic field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.general_statistics_setting_att.THEM

    @them.setter
    def them(self, value):
        """
        :param bool value:
        """

        self.general_statistics_setting_att.THEM = value

    @property
    def time(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property TIME() As boolean
                | 
                |     Returns or sets the state ot the time and date field.
                |     Role: Returns or sets the state ot the time and date
                |     field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.general_statistics_setting_att.TIME

    @time.setter
    def time(self, value):
        """
        :param bool value:
        """

        self.general_statistics_setting_att.TIME = value

    @property
    def time_unit(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property TimeUnit() As CATBSTR
                | 
                |     Returns or sets the state ot the time unit field.
                |     Role: Returns or sets the state ot the time unit field.
                | 
                |     Parameters:
                | 
                |         iTimeUnit
                |             Legal values:
                |             Second : durations are in seconds
                |             Millisecond: durations are in milliseconds

        :return: str
        """

        return self.general_statistics_setting_att.TimeUnit

    @time_unit.setter
    def time_unit(self, value):
        """
        :param str value:
        """

        self.general_statistics_setting_att.TimeUnit = value

    @property
    def upid(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property UPID() As boolean
                | 
                |     Returns or sets the state ot the user pid field.
                |     Role: Returns or sets the state ot the user pid field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.general_statistics_setting_att.UPID

    @upid.setter
    def upid(self, value):
        """
        :param bool value:
        """

        self.general_statistics_setting_att.UPID = value

    @property
    def user(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property USER() As boolean
                | 
                |     Returns or sets the state ot the user name field.
                |     Role: Returns or sets the state ot the user name field.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Legal values:
                |             TRUE : the field is activated
                |             FALSE: the field is not activated

        :return: bool
        """

        return self.general_statistics_setting_att.USER

    @user.setter
    def user(self, value):
        """
        :param bool value:
        """

        self.general_statistics_setting_att.USER = value

    def get_format_mode(self, flag):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetFormatMode(long flag) As boolean
                | 
                |     Returns the format mode of the statistics thematic.
                |     Role: Returns or sets the format mode of the statistics
                |     thematic.
                | 
                |     Parameters:
                | 
                |         oFormatMode
                |             Legal values:
                |             TRUE : the thematic output is formated (field="value").
                |             FALSE: the thematic output is not formated
                |             ("value").

        :param int flag:
        :return: bool
        """
        return bool(self.general_statistics_setting_att.GetFormatMode(flag))

    def get_thematics_parameter_info(self, admin_level, o_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetThematicsParameterInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves environment informations for the general statistics
                |     parameters.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :return: None
        """
        return self.general_statistics_setting_att.GetThematicsParameterInfo(admin_level, o_locked)

    def set_format_mode(self, i_format_mode, flag):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetFormatMode(boolean iFormatMode,
                | long flag)
                | 
                |     Sets the format mode of the statistics thematic.
                |     Role: Returns or sets the format mode of the statistics
                |     thematic.
                | 
                |     Parameters:
                | 
                |         iFormatMode
                |             Legal values:
                |             TRUE : the thematic output is formated (field="value").
                |             FALSE: the thematic output is not formated
                |             ("value").

        :param bool i_format_mode:
        :param int flag:
        :return: None
        """
        return self.general_statistics_setting_att.SetFormatMode(i_format_mode, flag)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_format_mode'
        # # vba_code = """
        # # Public Function set_format_mode(general_statistics_setting_att)
        # #     Dim iFormatMode (2)
        # #     general_statistics_setting_att.SetFormatMode iFormatMode
        # #     set_format_mode = iFormatMode
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_thematics_parameter_lock(self, i_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetThematicsParameterLock(boolean iLocked)
                | 
                |     Locks or unlocks the general statistics parameters.
                |     Role:Locks or unlocks the statistics parameters.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :return: None
        """
        return self.general_statistics_setting_att.SetThematicsParameterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_thematics_parameter_lock'
        # # vba_code = """
        # # Public Function set_thematics_parameter_lock(general_statistics_setting_att)
        # #     Dim iLocked (2)
        # #     general_statistics_setting_att.SetThematicsParameterLock iLocked
        # #     set_thematics_parameter_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'GeneralStatisticsSettingAtt(name="{ self.name }")'



#! /usr/bin/python3.6


class PYCATIABaseException(Exception):
    """
    PYCATIABaseException class.
    """
    pass


class CATIAApplicationException(PYCATIABaseException):
    """

    """

    def __init__(self, message):
        """

        :param message:
        """

        self.message = message
